pub struct Arena<const N: usize> { /* private fields */ }Expand description
Arena allocator for temporary allocations
Fast allocator for temporary objects that will all be freed together
Implementations
Sourceimpl<const N: usize> Arena<N>
impl<const N: usize> Arena<N>
Sourcepub fn allocate_typed<T>(&self) -> Result<NonNull<T>>
pub fn allocate_typed<T>(&self) -> Result<NonNull<T>>
Allocate a typed value
Returns a NonNull<T> pointer to properly aligned, uninitialized memory.
The caller is responsible for initializing the memory before use.
Errors
Returns error if insufficient space