PowerManager

Struct PowerManager 

pub struct PowerManager { /* private fields */ }
Power manager for controlling system power state

Implementations

Source

impl PowerManager

pub const fn new() -> Self

Create a new power manager in high performance mode

pub fn current_mode(&self) -> PowerMode

Get current power mode

pub fn request_mode(&self, mode: PowerMode) -> Result<()>

Request power mode transition

Errors

Returns error if transition is not allowed or fails